==> ejc-ztpcdc-impl-3.0.0-20230811.071921-173-sources.jar: com/ejianc/business/dc/controller/DcDrawrecycleInfoController.java <==
package com.ejianc.business.dc.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.basem.service.IAttachmentService;
import com.ejianc.business.dc.bean.DcDrawrecycleInfoEntity;
import com.ejianc.business.dc.enumUtils.RecycleEnum;
import com.ejianc.business.dc.service.IDcDrawrecycleInfoService;
import com.ejianc.business.dc.vo.DcDrawrecycleInfoVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 图纸回收
 *
 * @author generator
 */
@Controller
@RequestMapping("dcDrawrecycleInfo")
public class DcDrawrecycleInfoController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IOrgApi iOrgApi;
    @Autowired
    IAttachmentService iAttachmentService;

    public static final String BILL_CODE = "DC_DRAWRECYCLE_CODE";//此处需要根据实际修改

    @Autowired
    private IDcDrawrecycleInfoService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<DcDrawrecycleInfoVO> saveOrUpdate(@RequestBody DcDrawrecycleInfoVO saveOrUpdateVO) {
        DcDrawrecycleInfoEntity entity = BeanMapper.map(saveOrUpdateVO, DcDrawrecycleInfoEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            entity.setRecycleSts(RecycleEnum.N.getCode());
            entity.setCreateDeptId(sessionManager.getUserContext().getDeptId());
        }
        entity.getDcDrawrecycleDrwgrpinfoList().forEach(dcDrawrecycleDrwgrpinfoEntity -> dcDrawrecycleDrwgrpinfoEntity.setCreateDeptId(entity.getCreateDeptId()));
        entity.getDcDrawrecycleDrawinfoList().forEach(dcDrawrecycleDrawinfoEntity -> dcDrawrecycleDrawinfoEntity.setCreateDeptId(entity.getCreateDeptId()));
        service.saveOrUpdate(entity, false);
        entity.getDcDrawrecycleDrawinfoList().forEach(dcDrawrecycleDrawinfoEntity -> iAttachmentService.attachmentFile(
                dcDrawrecycleDrawinfoEntity.getDrawId(),
                "BT230602000000005",
                dcDrawrecycleDrawinfoEntity.getId(),
                "BT230602000000003"));
        DcDrawrecycleInfoVO vo = BeanMapper.map(entity, DcDrawrecycleInfoVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<DcDrawrecycleInfoVO> queryDetail(Long id) {
        DcDrawrecycleInfoEntity entity = service.selectById(id);
        DcDrawrecycleInfoVO vo = BeanMapper.map(entity, DcDrawrecycleInfoVO.class);
        vo.setRecycleStsCn(RecycleEnum.getEnumByCode(vo.getRecycleSts()).getName());
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    @RequestMapping(value = "/recycle", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> recycle(@RequestBody List<DcDrawrecycleInfoVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            service.recycle(vos);
        }
        return CommonResponse.success("图纸回收成功！");
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<DcDrawrecycleInfoVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (DcDrawrecycleInfoVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(DcDrawrecycleInfoVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<DcDrawrecycleInfoVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("drwgrpCode");
        fuzzyFields.add("drwgrpVsn");
        fuzzyFields.add("drwgrpName");
        fuzzyFields.add("issueUserName");
        fuzzyFields.add("recycleCode");
        fuzzyFields.add("recycleUserName");
        fuzzyFields.add("recycleDate");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        Long orgId = InvocationInfoProxy.getOrgId();
        //若当前上下文为项目部，则根据项目部Id来进行查询
        if (OrgVO.ORG_TYPE_DEPARTMENT.equals(Integer.valueOf(InvocationInfoProxy.getOrgType()))) {
            param.getParams().put("orgId", new Parameter(QueryParam.EQ, orgId));
        } else {
            CommonResponse<List<OrgVO>> orgResp = iOrgApi.findChildrenByParentIdWithoutProjectDept(orgId);
            if (!orgResp.isSuccess()) {
                logger.error("分页查询失败，获取当前本下组织信息失败, {}", orgResp.getMsg());
                return CommonResponse.error("查询失败，获取组织信息失败！");
            }
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgResp.getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<DcDrawrecycleInfoEntity> page = service.queryPage(param, false);
        IPage<DcDrawrecycleInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), DcDrawrecycleInfoVO.class));
        pageData.getRecords().forEach(e -> e.setRecycleStsCn(StringUtils.isBlank(e.getRecycleSts()) ? "" : RecycleEnum.getEnumByCode(e.getRecycleSts()).getName()));
        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<DcDrawrecycleInfoEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("DcDrawrecycleInfo-export.xlsx", beans, response);
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refDcDrawrecycleInfoData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<DcDrawrecycleInfoVO>> refDcDrawrecycleInfoData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                               String condition,
                                                                               String searchObject,
                                                                               String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<DcDrawrecycleInfoEntity> page = service.queryPage(param, false);
        IPage<DcDrawrecycleInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), DcDrawrecycleInfoVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }
}

==> ejc-ztpcdc-impl-3.0.0-20230829.023503-203-sources.jar: com/ejianc/business/dc/controller/DcDrawrecycleInfoController.java <==
package com.ejianc.business.dc.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.basem.service.IAttachmentService;
import com.ejianc.business.dc.bean.DcDrawrecycleInfoEntity;
import com.ejianc.business.dc.enumUtils.RecycleEnum;
import com.ejianc.business.dc.service.IDcDrawrecycleInfoService;
import com.ejianc.business.dc.vo.DcDrawrecycleInfoVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 图纸回收
 *
 * @author generator
 */
@Controller
@RequestMapping("dcDrawrecycleInfo")
public class DcDrawrecycleInfoController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IOrgApi iOrgApi;
    @Autowired
    IAttachmentService iAttachmentService;

    public static final String BILL_CODE = "DC_DRAWRECYCLE_CODE";//此处需要根据实际修改

    @Autowired
    private IDcDrawrecycleInfoService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<DcDrawrecycleInfoVO> saveOrUpdate(@RequestBody DcDrawrecycleInfoVO saveOrUpdateVO) {
        DcDrawrecycleInfoEntity entity = BeanMapper.map(saveOrUpdateVO, DcDrawrecycleInfoEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            entity.setRecycleSts(RecycleEnum.N.getCode());
            entity.setCreateDeptId(sessionManager.getUserContext().getDeptId());
        }
        entity.getDcDrawrecycleDrwgrpinfoList().forEach(dcDrawrecycleDrwgrpinfoEntity -> dcDrawrecycleDrwgrpinfoEntity.setCreateDeptId(entity.getCreateDeptId()));
        entity.getDcDrawrecycleDrawinfoList().forEach(dcDrawrecycleDrawinfoEntity -> dcDrawrecycleDrawinfoEntity.setCreateDeptId(entity.getCreateDeptId()));
        service.saveOrUpdate(entity, false);
        entity.getDcDrawrecycleDrawinfoList().forEach(dcDrawrecycleDrawinfoEntity -> iAttachmentService.attachmentFile(
                dcDrawrecycleDrawinfoEntity.getDrawId(),
                "BT230602000000005",
                dcDrawrecycleDrawinfoEntity.getId(),
                "BT230602000000003"));
        DcDrawrecycleInfoVO vo = BeanMapper.map(entity, DcDrawrecycleInfoVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<DcDrawrecycleInfoVO> queryDetail(Long id) {
        DcDrawrecycleInfoEntity entity = service.selectById(id);
        DcDrawrecycleInfoVO vo = BeanMapper.map(entity, DcDrawrecycleInfoVO.class);
        vo.setRecycleStsCn(RecycleEnum.getEnumByCode(vo.getRecycleSts()).getName());
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    @RequestMapping(value = "/recycle", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> recycle(@RequestBody List<Long> ids) {
        if (ListUtil.isNotEmpty(ids)) {
            service.recycle(ids);
        }
        return CommonResponse.success("图纸回收成功！");
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<DcDrawrecycleInfoVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (DcDrawrecycleInfoVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(DcDrawrecycleInfoVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<DcDrawrecycleInfoVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("drwgrpCode");
        fuzzyFields.add("drwgrpVsn");
        fuzzyFields.add("drwgrpName");
        fuzzyFields.add("issueUserName");
        fuzzyFields.add("recycleCode");
        fuzzyFields.add("recycleUserName");
        fuzzyFields.add("recycleDate");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        Long orgId = InvocationInfoProxy.getOrgId();
        //若当前上下文为项目部，则根据项目部Id来进行查询
        if (OrgVO.ORG_TYPE_DEPARTMENT.equals(Integer.valueOf(InvocationInfoProxy.getOrgType()))) {
            param.getParams().put("orgId", new Parameter(QueryParam.EQ, orgId));
        } else {
            CommonResponse<List<OrgVO>> orgResp = iOrgApi.findChildrenByParentIdWithoutProjectDept(orgId);
            if (!orgResp.isSuccess()) {
                logger.error("分页查询失败，获取当前本下组织信息失败, {}", orgResp.getMsg());
                return CommonResponse.error("查询失败，获取组织信息失败！");
            }
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgResp.getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<DcDrawrecycleInfoEntity> page = service.queryPage(param, false);
        IPage<DcDrawrecycleInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), DcDrawrecycleInfoVO.class));
        pageData.getRecords().forEach(e -> e.setRecycleStsCn(StringUtils.isBlank(e.getRecycleSts()) ? "" : RecycleEnum.getEnumByCode(e.getRecycleSts()).getName()));
        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<DcDrawrecycleInfoEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("DcDrawrecycleInfo-export.xlsx", beans, response);
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refDcDrawrecycleInfoData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<DcDrawrecycleInfoVO>> refDcDrawrecycleInfoData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                               String condition,
                                                                               String searchObject,
                                                                               String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<DcDrawrecycleInfoEntity> page = service.queryPage(param, false);
        IPage<DcDrawrecycleInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), DcDrawrecycleInfoVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }
}
